@@ -64,7 +64,7 @@ type Driver struct {
 	// ForceParams will be used to force parameters if defined.
 	ForceParams func(*dburl.URL)
 	// Open will be used by Open if defined.
-	Open func(*dburl.URL, func() io.Writer, func() io.Writer) (func(string, string) (*sql.DB, error), error)
+	Open func(context.Context, *dburl.URL, func() io.Writer, func() io.Writer) (func(string, string) (*sql.DB, error), error)
 	// Version will be used by Version if defined.
 	Version func(context.Context, DB) (string, error)
 	// User will be used by User if defined.
@@ -160,7 +160,7 @@ func ForceParams(u *dburl.URL) {
 }
 
 // Open opens a sql.DB connection for a driver.
-func Open(u *dburl.URL, stdout, stderr func() io.Writer) (*sql.DB, error) {
+func Open(ctx context.Context, u *dburl.URL, stdout, stderr func() io.Writer) (*sql.DB, error) {
 	d, ok := drivers[u.Driver]
 	if !ok {
 		return nil, WrapErr(u.Driver, text.ErrDriverNotAvailable)
@@ -168,7 +168,7 @@ func Open(u *dburl.URL, stdout, stderr func() io.Writer) (*sql.DB, error) {
 	f := sql.Open
 	if d.Open != nil {
 		var err error
-		if f, err = d.Open(u, stdout, stderr); err != nil {
+		if f, err = d.Open(ctx, u, stdout, stderr); err != nil {
 			return nil, WrapErr(u.Driver, err)
 		}
 	}
@@ -506,7 +506,7 @@ func Copy(ctx context.Context, u *dburl.URL, stdout, stderr func() io.Writer, ro
 	if d.Copy == nil {
 		return 0, fmt.Errorf(text.NotSupportedByDriver, "copy", u.Driver)
 	}
-	db, err := Open(u, stdout, stderr)
+	db, err := Open(ctx, u, stdout, stderr)
 	if err != nil {
 		return 0, err
 	}
